body {
    /* backdrop-filter: blur(4px) !important; */
    background-color: var(--background-color);
    color: var(--text-color);
}

.text-color {
    color: var(--text-color);
}

nav.navbar {
    align-items: center;
}

nav.navbar-mainbg.side {
    width: 100%;
    height: 100vh;
}

nav.navbar-mainbg.top,
nav.navbar-mainbg.under,
nav.navbar-mainbg.static {
    width: 100%;
    height: 3.75rem;
}

nav .dropdown-toggle:after {
    display: inline-block;
    vertical-align: .255em;
    content: ">";
    border: none;
    margin-left: auto;
}

nav.side:not(:has( > .nav-open)) .dropdown-toggle:after {
    padding: 0;
    margin: 0;
    margin-left: 0.5rem;
}

nav.side .navbar-wrapper.nav-close  ul.navbar-nav li.nav-item a {
    justify-content: center;
}

nav.collapsed:not(.side) .navbar-wrapper {
    width: 100%;
    position: absolute;
}

nav.side .navbar-wrapper {
    width: 100%;
}

nav.navbar:not(.side) .navbar-wrapper.nav-close {
    display: none;
}


nav.navbar.side .navbar-wrapper {
    flex-grow: 1;
}

.navbar-wrapper, .navbar-wrapper.nav-open {
    display: block;
}

.navbar-wrapper .nav-item .icon-placeholder {
    width: 24px;
    font-weight: bold;
    font-size: 1.2rem;
    text-align: center;
}

.navbar-wrapper .nav-item > a:not(:only-child):after {
    font-family: monospace;
}

.navbar-wrapper li.nav-item:has(ul.show) {
    background: var(--option_active_translucent);
}
.navbar-wrapper li.nav-item:has(ul.show) > a {
    color: var(--txc_active) !important;
}

.navbar-wrapper li.nav-item:has(ul.show) > a:after {
    -webkit-transform: rotate(90deg);
     transform: rotate(90deg)
}

.navbar-wrapper .nav-item:not(:has(ul.show)) > a:after {
    transform: none;
}

.navbar-nav>li>.dropdown-menu {
    position: absolute;
    width: 100%;
    min-width: unset;
    left: 0;
    top: 100%;
    background-color: var(--secondary-background-color);
    color: var(--txc_active)!important;
    border: none;
    /*border-radius: 15px; */
    border-radius: 0;
}
nav:not(.side) .navbar-nav>li>.dropdown-menu {
    max-height: calc(3.5*(3.75rem - 0.125rem - 0.15rem));
    overflow-y: auto;
}

nav.side .navbar-nav>li>.dropdown-menu {
    position: relative;
}

.navbar-toggler {
    position: relative;
    left: 0.5rem;
    /* height: 2.5rem; */
    display: flex;
    /* top: 0.5rem; */
    /* margin: 0.25rem 0.125rem; */
    padding: 0;
    font-size: 1rem;
    background-color: transparent;
    border: none;
    line-height: 1;
    border-radius: 0.25rem;
    outline: none !important;
    z-index: 10;
}


nav.side .navbar-toggler, nav.side .theme-toggler {
    position: relative;
    left: -0.125rem;
    margin-top: 1rem;
    margin-bottom: 1rem;
    padding: 0;
}
nav.side .navbar-toggler {
    display: block;
    position: sticky;
    top: 0;
}

nav .navbar-toggler[aria-expanded="true"] > span.menu-closed {
    display: none;
}
nav .navbar-toggler[aria-expanded="false"] > span.menu-open {
    display: none;
}

nav.navbar.side:has(.navbar-wrapper.nav-open) > .navbar-toggler, nav.navbar.side:has(.navbar-wrapper.nav-open) > .navbar-toggler > span {
    width: 95%;
}

nav.side .theme-toggler {
    margin-bottom: 2rem;
}

.navbar-nav {
    align-items: center;
}

.navbar-toggler > span:hover,
.theme-toggler > span:hover {
    background: var(--secondary-background-color);
}
.navbar-toggler:focus > span,
.theme-toggler:focus > span {
    box-shadow: var(--option_active_translucent) 0px 0px 0px 0.1rem
}
.theme-toggler:focus {
    outline: none;
}

.navbar-toggler:focus-visible > span,
.theme-toggler:focus-visible > span {
    box-shadow: var(--secondary-background-color) 0px 0px 0px 0.1rem
}

.navbar-toggler > i {
    scale: 1.5 1;
}


.navbar-wrapper li {
    position: initial;
}

.navbar-wrapper li.active {
    position: relative;
}

ul li a:has(.icon) {
    display: flex !important;
    align-items: center;
}

ul li a .icon {
    margin-right: 0.5rem;
    font-style: normal;
}
nav.side .navbar-wrapper.nav-close ul li a .icon {
    margin-right: 0;
}

.navbar-wrapper ul.navbar-nav li a span {
    white-space: nowrap;
}

.navbar-wrapper ul.navbar-nav li.nav-item a {
    background-color: transparent;
    color: var(--txc_inactive);
    border-radius: 0px;
    height: calc(3.75rem - 0.125rem - 0.15rem);
    display: flex;
    flex-direction: row;
    flex-wrap: nowrap;
    align-items: center;
}


.navbar-wrapper ul.navbar-nav li.nav-item:hover,
.navbar-wrapper ul.navbar-nav li.nav-item ul.dropdown-menu > li:hover,
.navbar-wrapper ul.navbar-nav li.nav-item:has(a:active),
.navbar-wrapper ul.navbar-nav li.nav-item:has(a:focus),
.navbar-wrapper ul.navbar-nav li.nav-item:has(a:focus-visible) {
    background: var(--option_active_translucent);
}

.navbar-wrapper ul.navbar-nav li.nav-item ul.show > li:hover > a {
    color: var(--txc_active) !important;
}

.navbar-wrapper ul.navbar-nav li.nav-item > a:active,
.navbar-wrapper ul.navbar-nav li.nav-item > a:focus,
.navbar-wrapper ul.navbar-nav li.nav-item > a:focus-visible,
.navbar-wrapper ul.navbar-nav li.nav-item ul.dropdown-menu > li > a:active,
.navbar-wrapper ul.navbar-nav li.nav-item ul.dropdown-menu > li > a:focus,
.navbar-wrapper ul.navbar-nav li.nav-item ul.dropdown-menu > li > a:focus-visible {
    color: var(--txc_active) !important;
}

.navbar-wrapper ul.navbar-nav li.nav-item > a:hover,
.navbar-wrapper ul.navbar-nav li.nav-item > a:hover a {
    color: var(--txc_active) !important;
}

.navbar-wrapper li.nav-item > a {
   border: none;
}


.navbar-wrapper > ul.navbar-nav > li {
    border-bottom: 0.25rem solid transparent;
}
nav:not(.side) .navbar-wrapper > ul.navbar-nav > li {
    padding-right: 0.5rem;
}
nav:not(.side) .navbar-wrapper > ul.navbar-nav > li > a > span.icon-placeholder {
    display: none;
}
nav.collapsed .navbar-wrapper > ul.navbar-nav > li > a > span.icon-placeholder {
    display: block;
}

nav:not(.side) .navbar-wrapper li.nav-item > a {
    border-left: 0.25rem solid transparent;
}
nav:not(.side) .navbar-wrapper li.nav-item[data-login="true"] {
    margin-left: auto;
}
nav.side .navbar-wrapper li.nav-item[data-login="true"] {
    margin-top: 1rem;
}
nav:not(.side) .navbar-wrapper li.nav-item[data-login="true"] > a {
    border-left: none;
    border-right: 0.25rem solid transparent;
}

nav.side .navbar-wrapper.nav-close > ul.navbar-nav > li.nav-item > a > span:not(.icon),
nav.side .navbar-wrapper.nav-close > ul.navbar-nav > li.nav-item > ul > li > a > span:not(.icon) {
    display: none;
}

.navbar-wrapper ul.navbar-nav li.nav-item:has(li.active) > a,
.navbar-wrapper ul.navbar-nav li.active > a {
    color: var(--option_active);
}
.navbar-wrapper ul.navbar-nav li.nav-item:has(li.active),
.navbar-wrapper > ul.navbar-nav > li.active {
    border-bottom: 0.25rem solid var(--option_active);
}

nav:not(.side) .navbar-wrapper li.nav-item li.active > a {
    /* background: var(--option_active_translucent); */
    border-left: 0.25rem solid var(--option_active);
}

nav.side .navbar-wrapper li.nav-item > a {
    border-right: 0.25rem solid transparent;
}
nav.side .navbar-wrapper li.nav-item li.active > a {
    border-right: 0.25rem solid var(--option_active);
}

.navbar-wrapper li.nav-item li.active[data-login="true"] > a {
    border-right: 0.25rem solid var(--option_active);
    border-left: none;
}

nav.navbar:not(.side):before {
    content: "";
    position: absolute;
    width: 100%;
    display: block;
    bottom: 0;
    z-index: 0;
    left: 0;
    height: 0.25rem;
    background: var(--secondary-background-color);
}

  /*i:hover {
    color: var(--txc_active);
  }*/

#navlogo{
    color: var(--txc_inactive);
}
#navlogo:hover{
    color: var(--txc_active);
}
.navbar-mainbg{
    background-color: var(--menu_background);
    padding: 0px;
}

ul.navbar-nav {
    width: 100%;
}

nav:not(.side) .navbar-nav {
    max-height: calc(5.5*(3.75rem - 0.125rem - 0.15rem));
    overflow-y: auto;
}

.navbar-wrapper ul{
    padding: 0px;
    margin: 0px;
}
.navbar-wrapper ul li a i{
    margin: 5px;
}
.navbar-wrapper li {
    list-style-type: none;
    float: center;
    height: 100%;
}
.navbar-wrapper ul li a{
    color: var(--txc_inactive);
    text-decoration: none;
    font-size: auto;
    display: block;
    padding: 0.5rem;
    padding-top: 1rem;
    transition-duration: 0.2s;
    transition-timing-function: cubic-bezier(0.23, -0.18, 0.09, 0.52);
    position: relative;
}
.navbar-wrapper>ul>li.active>a{
    color: var(--txc_active);
    background-color: transparent;
    /* transition: all 0.1s; */
    transition: none;
}
.navbar-wrapper a:not(:only-child):after {
    right: 5px;
    top: 0px;
    font-size: auto;
    display: inline-block;
    padding-right: 10px;
    padding-left: 10px;
    vertical-align: middle;
    font-weight: 900;
    transition: 0.1s;
}
.navbar-wrapper .active>a:not(:only-child):after {
    transform: rotate(90deg);
}


  /* @media(min-width: 992px){ */
nav.navbar.top:not(.collapsed),
nav.navbar.under:not(.collapsed),
nav.navbar.static:not(.collapsed) {
    & {
        -ms-flex-flow: row wrap;
        flex-flow: row wrap;
        -ms-flex-pack: start;
        justify-content: flex-start;
    }
    & .navbar-nav {
        -ms-flex-direction: row;
        flex-direction: row;
    }
    & .navbar-toggler {
        display: none;
    }
    & .navbar-collapse {
        display: -ms-flexbox!important;
        display: flex!important;
        -ms-flex-preferred-size: auto;
        flex-basis: auto;
        align-items: stretch;
    }
}


  /*@media (max-width: 991px){*/
nav.navbar.collapsed,
nav.navbar.side:not(.collapsed) {
    & .navbar-wrapper ul li a {
      padding: 0.5rem;
    }
    & .navbar-wrapper {
        top: 3.5rem;
    }
    & .navbar-wrapper ul.navbar-nav li.nav-item:has(li.active),
    & .navbar-wrapper > ul.navbar-nav > li.active {
        border-bottom: none;
    }
    & .navbar-nav {
        align-items: unset;
        padding-top: 0.125em !important;
    }
}

nav.navbar:not(.side).collapsed {
    & .navbar-wrapper ul.navbar-nav li.nav-item.active > a,
    & .navbar-wrapper ul.navbar-nav li.nav-item:has(li.active) > a {
       border-left: 4px solid var(--option_active);
       border-bottom: none;
    }
    & .navbar-wrapper ul.navbar-nav li.nav-item.active[data-login="true"] > a,
    & .navbar-wrapper ul.navbar-nav li.nav-item[data-login="true"]:has(li.active) > a {
        border-right: 4px solid var(--option_active);
        border-left: none;
    }
    & .navbar-wrapper > ul.navbar-nav > li {
        border-bottom: none;
    }
}

nav.navbar.side {
    display: flex;
    flex-wrap: nowrap;
    flex-direction: column;
    overflow-y: auto;

    & .navbar-wrapper ul.navbar-nav li.nav-item.active > a,
    & .navbar-wrapper ul.navbar-nav li.nav-item:has(li.active) > a {
        border-right: 4px solid var(--option_active) !important;
        border-left: none;
        border-bottom: none;
    }
    & .navbar-wrapper ul.navbar-nav li.nav-item:not(.active):has(> ul > li:not(.active)) > a {
        border-right: 4px solid transparent;
        border-left: none;
        border-bottom: none;
    }
    & .navbar-wrapper > ul.navbar-nav > li {
        border-bottom: none;
    }

    /* scrollbar styles */
    &::-webkit-scrollbar {
        width: 0.5rem;
    }
    &::-webkit-scrollbar-track {
        background: var(--secondary-background-color);
    }
    &::-webkit-scrollbar-thumb {
        background: #8686867a;
    }
}

#navbarSupportedContent {
    position: relative;
}

#navbarSupportedContent ul{
    padding: 0px;
    margin: 0px;
}
.navbar-wrapper ul li a i{
    margin: 5px;
}
#navbarSupportedContent li {
    list-style-type: none;
    float: center;
}
#navbarSupportedContent ul li a{
    color: var(--txc_inactive);
    text-decoration: none;
    font-size: auto;
    display: block;
    padding: 20px 20px;
    position: relative;
}
#navbarSupportedContent>ul>li.active>a{
    color: var(--txc_active);
    background-color: var(--option_active);
    border-radius: 15px;
}

.theme-toggler {
    border: none;
    display: flex;
    align-items: center;
    justify-content: center;
    background: transparent;
    border-radius: 0.5rem;
}

.theme-toggler > span, .navbar-toggler > span {
    padding: 0.5rem;
    border-radius: 0.5rem;
    background-color: var(--background-color);
}

.theme-toggler:hover > span {
    background: var(--secondary-background-color);
}